@@ -32,15 +32,17 @@ class PromptDialog : public Gtk::Dialog {
   enum PromptType {
     PROMPT_WARNING,
     PROMPT_CONFIRM,
-    PROMPT_QUESTION
+    PROMPT_QUESTION,
+    PROMPT_INFO
   };
 
  private:
-  PromptType type;
-  bool finish_bool;
+  PromptType m_type;
+  bool m_finish_bool;
+  bool m_modal;
 
  public:
-  PromptDialog(PromptType t, const string& msg);
+  PromptDialog(Gtk::Window * parent, PromptType t, const string& msg, bool modal = true);
 
   bool run();
 
